# -*- coding: utf-8 -*-
# @Author: Haut-Stone
# @Date:   2017-09-30 09:56:23
# @Last Modified by:   Haut-Stone
# @Last Modified time: 2017-09-30 09:56:40


cookies = {
	'DedeUserID': '221013145',
	'DedeUserID__ckMd5': '0ada37d8e37bee1f',
	'SESSDATA': 'ddff3d5b%2C1508937653%2C5dc59211'
}
